@@ -23,16 +23,10 @@
  * SPDX-License-Identifier: curl
  *
  ***************************************************************************/
-
 #include "curl_setup.h"
 
 #include "hash.h"
-#include "curl_addrinfo.h"
-#include "curlx/timeval.h" /* for timediff_t */
-#include "asyn.h"
-#include "httpsrr.h"
-
-#include <setjmp.h>
+#include "curlx/timeval.h" /* for curltime, timediff_t */
 
 #ifdef USE_HTTPSRR
 # include <stdint.h>
@@ -53,6 +47,7 @@ struct hostent;
 struct Curl_easy;
 struct connectdata;
 struct easy_pollset;
+struct Curl_https_rrinfo;
 
 enum alpnid {
   ALPN_none = 0,
